//
//  Arrows.swift
//  Kaktovik Introduction
//
//  Created by Linus Plohr on 1/2/24.
//

import SwiftUI

struct ForwardArrow: View {
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.page_list.append(navigation.current_page)
            navigation.current_page = navigation.current_page + 1
            print("ForwardArrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Image(systemName: "arrowshape.forward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct BackwardArrow: View {
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            if let top = navigation.page_list.popLast() {
                navigation.current_page = top
            }
            else {
                navigation.current_page = 0
            }
            print("BackwardArrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Image(systemName: "arrowshape.backward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct BothArrows: View {
    @ObservedObject var navigation: Navigation

    var body: some View {
        HStack {
            BackwardArrow(navigation: navigation)
                .padding([.trailing], 100)
            ForwardArrow(navigation: navigation)
        }
    }
}

struct IntroArrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.page_list.append(navigation.current_page)
            navigation.current_page = navigation.intro_first_page
            print("IntroArrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Text(label)
                .foregroundColor(.white)
            Image(systemName: "arrowshape.forward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct IntroBackArrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.current_page = navigation.intro_first_page
            navigation.page_list = [navigation.current_page]
            print("IntroBackArrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Image(systemName: "arrowshape.backward")
                .foregroundColor(.white)
                .imageScale(.large)
            Text(label)
                .foregroundColor(.white)

        }
    }
}

struct LessonsArrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.page_list.append(navigation.current_page)
            navigation.current_page = navigation.lessons_page
            print("LessonsArrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Text(label)
                .foregroundColor(.white)
            Image(systemName: "arrowshape.forward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct LessonsBackArrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.current_page = navigation.lessons_page
            navigation.page_list = [navigation.current_page]
            print("LessonsBackArrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Text(label)
                .foregroundColor(.white)
            Image(systemName: "arrowshape.backward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct Lesson1Arrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.page_list.append(navigation.current_page)
            navigation.current_page = navigation.lesson_1_first_page
            print("Lesson1Arrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Text(label)
                .foregroundColor(.white)
            Image(systemName: "arrowshape.forward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct Lesson2Arrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.page_list.append(navigation.current_page)
            navigation.current_page = navigation.lesson_2_first_page
            print("Lesson2Arrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Text(label)
                .foregroundColor(.white)
            Image(systemName: "arrowshape.forward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct Lesson3Arrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.page_list.append(navigation.current_page)
            navigation.current_page = navigation.lesson_3_first_page
            print("Lesson3Arrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Text(label)
                .foregroundColor(.white)
            Image(systemName: "arrowshape.forward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct Lesson4Arrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.page_list.append(navigation.current_page)
            navigation.current_page = navigation.lesson_4_first_page
            print("Lesson4Arrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Text(label)
                .foregroundColor(.white)
            Image(systemName: "arrowshape.forward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct Quiz1ForwardArrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.page_list.append(navigation.current_page)
            var top = navigation.current_page
            while (top == navigation.current_page) {
                let first_page = navigation.quiz_1_first_page
                let last_page = navigation.quiz_1_last_page
                top = Int.random(in: first_page...last_page)
            }
            navigation.current_page = top
            print("Quiz1ForwardArrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Text(label)
                .foregroundColor(.white)
            Image(systemName: "arrowshape.forward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct Quiz1BothArrows: View {
    @ObservedObject var navigation: Navigation

    var body: some View {
        HStack {
            BackwardArrow(navigation: navigation)
                .padding([.trailing], 100)
            Quiz1ForwardArrow(label: "", navigation: navigation)
        }
    }
}

struct Quiz2ForwardArrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.page_list.append(navigation.current_page)
            var top = navigation.current_page
            while (top == navigation.current_page) {
                let first_page = navigation.quiz_2_first_page
                let last_page = navigation.quiz_2_last_page
                top = Int.random(in: first_page...last_page)
            }
            navigation.current_page = top
            print("Quiz2ForwardArrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Text(label)
                .foregroundColor(.white)
            Image(systemName: "arrowshape.forward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct Quiz2BothArrows: View {
    @ObservedObject var navigation: Navigation

    var body: some View {
        HStack {
            BackwardArrow(navigation: navigation)
                .padding([.trailing], 100)
            Quiz2ForwardArrow(label: "", navigation: navigation)
        }
    }
}

struct Quiz3ForwardArrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.page_list.append(navigation.current_page)
            var top = navigation.current_page
            while (top == navigation.current_page) {
                let first_page = navigation.quiz_3_first_page
                let last_page = navigation.quiz_3_last_page
                top = Int.random(in: first_page...last_page)
            }
            navigation.current_page = top
            print("Quiz3ForwardArrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
            Text(label)
                .foregroundColor(.white)
            Image(systemName: "arrowshape.forward")
                .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct Quiz3BothArrows: View {
    @ObservedObject var navigation: Navigation

    var body: some View {
        HStack {
            BackwardArrow(navigation: navigation)
                .padding([.trailing], 100)
            Quiz3ForwardArrow(label: "", navigation: navigation)
        }
    }
}

struct Quiz4ForwardArrow: View {
    var label: String
    @ObservedObject var navigation: Navigation

    var body: some View {
        Button {
            navigation.page_list.append(navigation.current_page)
            var top = navigation.current_page
            while (top == navigation.current_page) {
                let first_page = navigation.quiz_4_first_page
                let last_page = navigation.quiz_4_last_page
                top = Int.random(in: first_page...last_page)
            }
           navigation.current_page = top
            print("Quiz4ForwardArrow: current_page = \(navigation.current_page); page_list = \(navigation.page_list)")
        } label: {
           Text(label)
               .foregroundColor(.white)
            Image(systemName: "arrowshape.forward")
              .foregroundColor(.white)
                .imageScale(.large)
        }
    }
}

struct Quiz4BothArrows: View {
    @ObservedObject var navigation: Navigation

    var body: some View {
        HStack {
            BackwardArrow(navigation: navigation)
                .padding([.trailing], 100)
            Quiz4ForwardArrow(label: "", navigation: navigation)
        }
    }
}

struct Lesson5Arrow: View {
    @ObservedObject var navigation: Navigation

    var body: some View {
        HStack {
            BackwardArrow(navigation: navigation)
                .padding([.trailing], 100)
        }
    }
}
