//
//  Cover.swift
//  Kaktovik Introduction
//
//  Created by Linus Plohr on 2/4/24.
//

import SwiftUI

struct Cover: View {
    @ObservedObject var navigation: Navigation

    var body: some View {
        guard UIFont(name: "Gentium Kaktovik", size: UIFont.labelFontSize) != nil else {
            fatalError("""
                    Failed to load the "Gentium Kaktovik" font.
                """
            )
        }
        
        return ZStack {
            Color.purple
                .ignoresSafeArea()
            
            VStack {
                Spacer()

                Text("DuoNumero")
                    .font(Font.custom("Roman", size: 64))
                    .fontWeight(.bold)
                    .foregroundColor(.white)

                Spacer()
                Text("Kaktovik")
                    .font(Font.custom("Roman", size: 48))
                    .fontWeight(.bold)
                    .foregroundColor(.white)
                Text("Numerals")
                    .font(Font.custom("Roman", size: 48))
                    .fontWeight(.bold)
                    .foregroundColor(.white)
                
                Image("Logo")
                    .resizable()
                    .scaledToFit()
 
                Spacer()
                Text("\u{1d2c7}\u{1d2d3}")
                    .font(Font.custom("Gentium Kaktovik", size: 128))
                    .foregroundColor(.white)
                    .padding()
                    .padding()
                
                Spacer()
                IntroArrow(label: "Go to Introduction", navigation: navigation)
                LessonsArrow(label: "Go to Lessons", navigation: navigation)
            }
        }
    }
}

#Preview {
    @StateObject var navigation = Navigation()

    navigation.current_page = 0
    navigation.page_list = [navigation.current_page]

    return Cover(navigation: navigation)
}
